@@ -17,6 +17,9 @@
 # A CAM signature/authentication error occurred.
 AUTHFAILURE = 'AuthFailure'
 
+# 
+AUTHFAILURE_GETROLEFAILED = 'AuthFailure.GetRoleFailed'
+
 # Request unauthorized.
 AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 
